@@ -220,11 +220,12 @@ class User(VkontakteIDModel):
 
     def save(self, *args, **kwargs):
         # check strings for good encoding
-        # there is problems to save users with bad encoded activity strings like ID=88798245
-        try:
-            self.activity.encode('utf-16').decode('utf-16')
-        except UnicodeDecodeError:
-            self.activity = ''
+        # there is problems to save users with bad encoded activity strings like ID=88798245, ID=143523733
+        for field in ['activity','games','movies','tv','books','about','interests']:
+            try:
+                getattr(self, field).encode('utf-16').decode('utf-16')
+            except UnicodeDecodeError:
+                setattr(self, field, '')
 
         return super(User, self).save(*args, **kwargs)
 
@@ -292,7 +293,7 @@ class User(VkontakteIDModel):
     def fetch_posts(self, *args, **kwargs):
         if 'vkontakte_wall' in settings.INSTALLED_APPS:
             from vkontakte_wall.models import Post
-            return Post.remote.fetch_user_wall(self, *args, **kwargs)
+            return Post.remote.fetch_user_wall(user=self, *args, **kwargs)
         else:
             raise ImproperlyConfigured("Application 'vkontakte_wall' not in INSTALLED_APPS")
 
@@ -317,6 +318,8 @@ class User(VkontakteIDModel):
         self.friends_count = self.friends_users.count()
         self.save()
 
+        return self.friends_users.all()
+
     @property
     def is_deactivated(self):
         return self.photo_big == USER_PHOTO_DEACTIVATED_URL
@@ -325,4 +328,12 @@ class User(VkontakteIDModel):
         return self.photo_big != USER_NO_PHOTO_URL
 
     def get_sex(self):
-        return dict(USER_SEX_CHOICES).get(self.sex)
\ No newline at end of file
+        return dict(USER_SEX_CHOICES).get(self.sex)
+
+    @property
+    def wall_comments(self):
+        if 'vkontakte_wall' in settings.INSTALLED_APPS:
+            from vkontakte_wall.models import Comment
+            return Comment.objects.filter(remote_id__startswith='%s_' % self.remote_id)
+        else:
+            raise ImproperlyConfigured("Application 'vkontakte_wall' not in INSTALLED_APPS")
\ No newline at end of file
